/* BurpExtender.java - Burp extender main class
 *
 * Automated modification of websockets messages requires the implementation of
 * a Java class that implements the interface evilwan.WSFIlter That implementation class
 * should have a constructor that is to be called without arguments.
 *
 * Note: this implementation of a Burp extension only works with Burp Professional version 1.7.04
 *
 * Since the previous supported version, the internal workings of Burp have been changed
 * so much that much of the automatic reverse engineering that was implemented in the extension
 * no longer works. So this version no longer tries to be version independent anymore. Instead,
 * the new code base was analyzed using debug versions of this extension that dumped interesting
 * objects and classes, as well as the use of Procyon, a Java decompiler (although pretty limited,
 * mainly for looking at which variables were used in methods like getRowCount() because they
 * have to lead the actual websocket message data) The final step was using Burp to intercept
 * and modify websocket messages so that the correct accessor methods could be identified.
 *
 * Enjoy.
 *
 * Copyright (c) 2016 Eddy Vanlerberghe.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of Eddy Vanlerberghe shall not be used to endorse or promote
 *    products derived from this software without specific prior written
 *    permission.
 *
 * THIS SOFTWARE IS PROVIDED BY EDDY VANLERBERGHE ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL EDDY VANLERBERGHE BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

package burp;

import evilwan.*;
import java.awt.*;

public class BurpExtender implements IBurpExtender, ITab {
    // {{ Class members }}

    /**
     * Tab title for extension pane in GUI
     */
    private final static String TAB_CAPTION = "WS Stuff";
    /**
     * Identification to show in overview of loaded extensions
     */
    private final static String EXT_NAME = "WebSockets Stuff v1.7.04";

    // {{ Instance members }}
    
    /**
     * For interaction with Burp from within the extension
     */
    private IBurpExtenderCallbacks	_cb = null;
    /**
     * Pane in GUI for interaction with the extension.
     */
    private Component			_tabpane = null;

    // {{ Class methods }}
    
    // {{ Constructors }}
    
    // {{ Instance methods }}

    //
    // IBurpExtender interface
    //
    /**
     * Main entry point for Burp extension
     *
     * @param cb set of callback methods for interaction from within the
     * extension with the rest of the Burp environment,
     */
    public void registerExtenderCallbacks(IBurpExtenderCallbacks cb) {
	_cb = cb;
	_cb.setExtensionName(EXT_NAME);
	_tabpane = new WSGui();
	_cb.addSuiteTab(this);
	String[] args = _cb.getCommandLineArguments();
	int i = 0;
	while(i < args.length) {
	    if(args[i].equals("-XXX")) {
		WSPacket.setDebug(true);
	    }
	}
    }
    
    //
    // ITab interface
    //
    public String getTabCaption() {
	return TAB_CAPTION;
    }
    public Component getUiComponent() {
	return _tabpane;
    }
}
